==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/zh_TW.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "與您分享",
    "Shared with others" : "與其他人分享",
    "Shared by link" : "由連結分享",
    "Nothing shared with you yet" : "目前沒有任何與您分享的內容",
    "Files and folders others share with you will show up here" : "與您分享的檔案與資料夾將會顯示在這裡",
    "Nothing shared yet" : "目前沒有分享內容",
    "Files and folders you share will show up here" : "您分享的檔案與資料夾將會顯示在這裡",
    "No shared links" : "沒有已分享的連結",
    "Files and folders you share by link will show up here" : "您分享的檔案與資料夾連結將會顯示在這裡",
    "You can upload into this folder" : "你可以上傳內容到此資料夾",
    "No compatible server found at {remote}" : "沒有在 {remote} 找到相容的伺服器",
    "Invalid server URL" : "無效的伺服器 URL",
    "Failed to add the public link to your Nextcloud" : "無法將公開連結加入您的 Nextcloud",
    "Share" : "分享",
    "No expiration date set" : "未指定到期日",
    "Shared by" : "分享自",
    "Sharing" : "分享",
    "File shares" : "檔案分享",
    "Downloaded via public link" : "透過公用連結下載",
    "Downloaded by {email}" : "{email} 已下載",
    "{file} downloaded via public link" : "{file} 已透過公用連結下載",
    "{email} downloaded {file}" : "{email} 已下載 {file}",
    "Shared with group {group}" : "與群組 {group} 分享",
    "Removed share for group {group}" : "移除與群組 {group} 分享",
    "{actor} shared with group {group}" : "{actor} 分享給群組 {group}",
    "{actor} removed share for group {group}" : "{actor} 移除了與群組 {group} 的分享",
    "You shared {file} with group {group}" : "你分享了 {file} 給群組 {group}",
    "You removed group {group} from {file}" : "你將群組 {group} 從 {file} 移除",
    "{actor} shared {file} with group {group}" : "{actor} 分享 {file} 給群組 {group}",
    "{actor} removed group {group} from {file}" : "{actor} 將群組 {group} 從 {file} 移除",
    "Shared as public link" : "藉由公用連結分享",
    "Removed public link" : "刪除公開連結",
    "Public link expired" : "公開連結已過期",
    "{actor} shared as public link" : "{actor} 透過公開連結分享",
    "{actor} removed public link" : "{actor} 移除公開連結分享",
    "Public link of {actor} expired" : "{actor} 的公開連結過期了",
    "You shared {file} as public link" : "你藉由公用連結分享了 {file}",
    "You removed public link for {file}" : "您刪除了 {file} 的公開分享連結",
    "Public link expired for {file}" : "{file} 的公開連結已過期",
    "{actor} shared {file} as public link" : "{actor} 透過公開連結分享 {file}",
    "{actor} removed public link for {file}" : "{actor} 移除 {file} 的公開連結分享",
    "Public link of {actor} for {file} expired" : "{actor} 公開分享 {file} 的連結過期了",
    "{user} accepted the remote share" : "{user} 接受了遠端分享",
    "{user} declined the remote share" : "{user} 拒絕了遠端分享",
    "You received a new remote share {file} from {user}" : "您收到了一個遠端分享 {file} 來自於 {user}",
    "{user} accepted the remote share of {file}" : "{user} 接受了檔案 {file} 的遠端分享",
    "{user} declined the remote share of {file}" : "{user} 拒絕了檔案 {file} 的遠端分享",
    "{user} unshared {file} from you" : "{user} 取消與你分享檔案 {file}",
    "Shared with {user}" : "與 {user} 分享",
    "Removed share for {user}" : "移除對 {user} 的分享",
    "{actor} shared with {user}" : "{actor} 分享給 {user}",
    "{actor} removed share for {user}" : "{actor} 移除了對 {user} 的分享",
    "Shared by {actor}" : "由 {actor} 分享",
    "{actor} removed share" : "{actor} 移除了分享",
    "You shared {file} with {user}" : "你與 {user} 分享了 {file}",
    "You removed {user} from {file}" : "你將 {user} 從 {file} 移除",
    "{actor} shared {file} with {user}" : "{actor} 分享了 {file} 給 {user}",
    "{actor} removed {user} from {file}" : "{actor} 移除 {user} 從 {file}",
    "{actor} shared {file} with you" : "{actor} 與你分享了 {file}",
    "{actor} removed you from {file}" : "{actor} 將你從 {file} 移除",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "email或公開連結分享的檔案與資料夾已被 <strong>下載</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "檔案或目錄已被 <strong>其他伺服器</strong> 分享",
    "A file or folder has been <strong>shared</strong>" : "檔案或目錄已被 <strong>分享</strong>",
    "Wrong share ID, share doesn't exist" : "錯誤的分享 ID ，分享不存在",
    "could not delete share" : "無法刪除分享",
    "Could not delete share" : "無法刪除分享",
    "Please specify a file or folder path" : "請指定檔案或資料夾路徑",
    "Wrong path, file/folder doesn't exist" : "錯誤的路徑，該檔案或資料夾不存在",
    "Could not create share" : "無法建立分享",
    "invalid permissions" : "無效的權限",
    "Please specify a valid user" : "請選擇一個有效的使用者",
    "Group sharing is disabled by the administrator" : "群組分享已被管理員停用",
    "Please specify a valid group" : "請指定一個有效的群組",
    "Public link sharing is disabled by the administrator" : "公開連結分享已被管理員停用",
    "Public upload disabled by the administrator" : "公開上傳已被管理員停用",
    "Public upload is only possible for publicly shared folders" : "只有公開分享的資料夾可以接受公開上傳",
    "Invalid date, date format must be YYYY-MM-DD" : "無效的日期，需為 YYYY-MM-DD 格式",
    "Sharing %s failed because the back end does not allow shares from type %s" : "分享 %s 失敗，因為後端不允許來自 %s 類型的分享",
    "You cannot share to a Circle if the app is not enabled" : "當應用未被啟用，你無法分享到circle。",
    "Please specify a valid circle" : "請指定一個有效的circle",
    "Unknown share type" : "未知的分享類型",
    "Not a directory" : "這不是一個資料夾",
    "Could not lock path" : "無法鎖定路徑",
    "Wrong or no update parameter given" : "更新參數不正確或未提供",
    "Can't change permissions for public share links" : "無法由公開分享的連結變更權限",
    "Cannot increase permissions" : "無法增加權限",
    "%s is publicly shared" : "%s 是被公然分享的",
    "Share API is disabled" : "分享 API 已停用",
    "File sharing" : "檔案分享",
    "This share is password-protected" : "這個分享有密碼保護",
    "The password is wrong. Try again." : "請檢查您的密碼並再試一次",
    "Password" : "密碼",
    "No entries found in this folder" : "在此資料夾中沒有任何項目",
    "Name" : "名稱",
    "Share time" : "分享時間",
    "Expiration date" : "到期日",
    "Sorry, this link doesn’t seem to work anymore." : "抱歉，此連結已經失效",
    "Reasons might be:" : "可能的原因：",
    "the item was removed" : "項目已經移除",
    "the link expired" : "連結過期",
    "sharing is disabled" : "分享功能已停用",
    "For more info, please ask the person who sent this link." : "請詢問告訴您此連結的人以瞭解更多",
    "shared by %s" : "分享自 %s",
    "Add to your Nextcloud" : "加入到您的 Nextcloud",
    "Download" : "下載",
    "Download %s" : "下載 %s",
    "Direct link" : "直接連結",
    "Upload files to %s" : "上傳檔案到 %s",
    "Select or drop files" : "選擇或拖曳檔案至此",
    "Uploading files…" : "上傳檔案中…",
    "Uploaded files:" : "已上傳的檔案："
},
"nplurals=1; plural=0;");

==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/zh_TW.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with others" : "與其他人分享",
    "Shared with you" : "與您分享",
    "Shared by link" : "由連結分享",
    "Nothing shared with you yet" : "目前沒有任何與您分享的內容",
    "Files and folders others share with you will show up here" : "與您分享的檔案與資料夾將會顯示在這裡",
    "Nothing shared yet" : "目前沒有分享內容",
    "Files and folders you share will show up here" : "您分享的檔案與資料夾將會顯示在這裡",
    "No shared links" : "沒有已分享的連結",
    "Files and folders you share by link will show up here" : "您分享的檔案與資料夾連結將會顯示在這裡",
    "You can upload into this folder" : "你可以上傳內容到此資料夾",
    "No compatible server found at {remote}" : "沒有在 {remote} 找到相容的伺服器",
    "Invalid server URL" : "無效的伺服器 URL",
    "Failed to add the public link to your Nextcloud" : "無法將公開連結加入您的 Nextcloud",
    "Share" : "分享",
    "No expiration date set" : "未指定到期日",
    "Shared by" : "分享自",
    "Sharing" : "分享",
    "File shares" : "檔案分享",
    "Downloaded via public link" : "透過公用連結下載",
    "Downloaded by {email}" : "{email} 已下載",
    "{file} downloaded via public link" : "{file} 已透過公用連結下載",
    "{email} downloaded {file}" : "{email} 已下載 {file}",
    "Shared with group {group}" : "與群組 {group} 分享",
    "Removed share for group {group}" : "移除與群組 {group} 分享",
    "{actor} shared with group {group}" : "{actor} 分享給群組 {group}",
    "{actor} removed share for group {group}" : "{actor} 移除了與群組 {group} 的分享",
    "You shared {file} with group {group}" : "你分享了 {file} 給群組 {group}",
    "You removed group {group} from {file}" : "你將群組 {group} 從 {file} 移除",
    "{actor} shared {file} with group {group}" : "{actor} 分享 {file} 給群組 {group}",
    "{actor} removed group {group} from {file}" : "{actor} 將群組 {group} 從 {file} 移除",
    "Shared as public link" : "藉由公用連結分享",
    "Removed public link" : "刪除公開連結",
    "Public link expired" : "公開連結已過期",
    "{actor} shared as public link" : "{actor} 透過公開連結分享",
    "{actor} removed public link" : "{actor} 移除公開連結分享",
    "Public link of {actor} expired" : "{actor} 的公開連結過期了",
    "You shared {file} as public link" : "你藉由公用連結分享了 {file}",
    "You removed public link for {file}" : "您刪除了 {file} 的公開分享連結",
    "Public link expired for {file}" : "{file} 的公開連結已過期",
    "{actor} shared {file} as public link" : "{actor} 透過公開連結分享 {file}",
    "{actor} removed public link for {file}" : "{actor} 移除 {file} 的公開連結分享",
    "Public link of {actor} for {file} expired" : "{actor} 公開分享 {file} 的連結過期了",
    "{user} accepted the remote share" : "{user} 接受了遠端分享",
    "{user} declined the remote share" : "{user} 拒絕了遠端分享",
    "You received a new remote share {file} from {user}" : "您收到了一個遠端分享 {file} 來自於 {user}",
    "{user} accepted the remote share of {file}" : "{user} 接受了檔案 {file} 的遠端分享",
    "{user} declined the remote share of {file}" : "{user} 拒絕了檔案 {file} 的遠端分享",
    "{user} unshared {file} from you" : "{user} 取消與你分享檔案 {file}",
    "Shared with {user}" : "與 {user} 分享",
    "Removed share for {user}" : "移除對 {user} 的分享",
    "{actor} shared with {user}" : "{actor} 分享給 {user}",
    "{actor} removed share for {user}" : "{actor} 移除了對 {user} 的分享",
    "Shared by {actor}" : "由 {actor} 分享",
    "{actor} removed share" : "{actor} 移除了分享",
    "You shared {file} with {user}" : "你與 {user} 分享了 {file}",
    "You removed {user} from {file}" : "你將 {user} 從 {file} 移除",
    "{actor} shared {file} with {user}" : "{actor} 分享了 {file} 給 {user}",
    "{actor} removed {user} from {file}" : "{actor} 移除 {user} 從 {file}",
    "{actor} shared {file} with you" : "{actor} 與你分享了 {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "email或公開連結分享的檔案與資料夾已被 <strong>下載</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "檔案或目錄已被 <strong>其他伺服器</strong> 分享",
    "A file or folder has been <strong>shared</strong>" : "檔案或目錄已被 <strong>分享</strong>",
    "Wrong share ID, share doesn't exist" : "錯誤的分享 ID ，分享不存在",
    "could not delete share" : "無法刪除分享",
    "Could not delete share" : "無法刪除分享",
    "Please specify a file or folder path" : "請指定檔案或資料夾路徑",
    "Wrong path, file/folder doesn't exist" : "錯誤的路徑，該檔案或資料夾不存在",
    "Could not create share" : "無法建立分享",
    "invalid permissions" : "無效的權限",
    "Please specify a valid user" : "請選擇一個有效的使用者",
    "Group sharing is disabled by the administrator" : "群組分享已被管理員停用",
    "Please specify a valid group" : "請指定一個有效的群組",
    "Public link sharing is disabled by the administrator" : "公開連結分享已被管理員停用",
    "Public upload disabled by the administrator" : "公開上傳已被管理員停用",
    "Public upload is only possible for publicly shared folders" : "只有公開分享的資料夾可以接受公開上傳",
    "Invalid date, date format must be YYYY-MM-DD" : "無效的日期，需為 YYYY-MM-DD 格式",
    "Sharing %s failed because the back end does not allow shares from type %s" : "分享 %s 失敗，因為後端不允許來自 %s 類型的分享",
    "You cannot share to a Circle if the app is not enabled" : "當應用未被啟用，你無法分享到circle。",
    "Please specify a valid circle" : "請指定一個有效的circle",
    "Unknown share type" : "未知的分享類型",
    "Not a directory" : "這不是一個資料夾",
    "Could not lock path" : "無法鎖定路徑",
    "Wrong or no update parameter given" : "更新參數不正確或未提供",
    "Can't change permissions for public share links" : "無法由公開分享的連結變更權限",
    "Cannot increase permissions" : "無法增加權限",
    "shared by %s" : "分享自 %s",
    "Download" : "下載",
    "Direct link" : "直接連結",
    "Add to your Nextcloud" : "加入到您的 Nextcloud",
    "Share API is disabled" : "分享 API 已停用",
    "No entries found in this folder" : "在此資料夾中沒有任何項目",
    "Name" : "名稱",
    "Share time" : "分享時間",
    "Expiration date" : "到期日",
    "Sorry, this link doesn’t seem to work anymore." : "抱歉，此連結已經失效",
    "Reasons might be:" : "可能的原因：",
    "the item was removed" : "項目已經移除",
    "the link expired" : "連結過期",
    "sharing is disabled" : "分享功能已停用",
    "For more info, please ask the person who sent this link." : "請詢問告訴您此連結的人以瞭解更多",
    "Download %s" : "下載 %s",
    "Upload files to %s" : "上傳檔案到 %s",
    "Select or drop files" : "選擇或拖曳檔案至此",
    "Uploading files…" : "上傳檔案中…",
    "Uploaded files:" : "已上傳的檔案：",
    "{actor} removed you from {file}" : "{actor} 將你從 {file} 移除",
    "This share is password-protected" : "這個分享有密碼保護",
    "The password is wrong. Try again." : "請檢查您的密碼並再試一次",
    "Password" : "密碼"
},
"nplurals=1; plural=0;");
